"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MysqlPlugin_1 = require("../mysql/MysqlPlugin");
const PostgresPlugin_1 = require("../postgres/PostgresPlugin");
const SqsWorkerPlugin_1 = require("../sqs/SqsWorkerPlugin");
const SqsClientPlugin_1 = require("../sqs/SqsClientPlugin");
const ElasticsearchPlugin_1 = require("../elasticsearch/ElasticsearchPlugin");
const AutowirePlugin_1 = require("./AutowirePlugin");
const LazyLoadingPlugin_1 = require("./LazyLoadingPlugin");
const StartStopPlugin_1 = require("./StartStopPlugin");
const BaseApp_1 = require("./BaseApp");
class InceptumApp extends BaseApp_1.default {
    /**
     * Creates a new Inceptum App
     */
    constructor(options = {}) {
        super(options);
        // Standard IOC plugins.
        this.register(new AutowirePlugin_1.default(), new LazyLoadingPlugin_1.default(), new StartStopPlugin_1.default());
        // TODO This is for backward compat, I'd like to remove it and be explicit
        if (this.hasConfig('mysql')) {
            this.logger.debug('Mysql Detected - Adding Plugin');
            this.register(new MysqlPlugin_1.default());
        }
        if (this.hasConfig('postgres')) {
            this.logger.debug('Postgres Detected - Adding Plugin');
            this.register(new PostgresPlugin_1.default());
        }
        if (this.hasConfig('SqsClient')) {
            this.logger.debug('SqsClient Detected - Adding Plugin');
            this.register(new SqsClientPlugin_1.default());
        }
        if (this.hasConfig('SqsWorker')) {
            this.logger.debug('SqsClient Detected - Adding Plugin');
            this.register(new SqsWorkerPlugin_1.default());
        }
        if (this.hasConfig('elasticsearch')) {
            this.logger.debug('elasticsearch Detected - Adding Plugin');
            this.register(new ElasticsearchPlugin_1.default());
        }
    }
}
exports.InceptumApp = InceptumApp;
//# sourceMappingURL=InceptumApp.js.map